/*
 * cgi-query.C
 */
/*
    This file is a CGI Script interface
    Copyright (C) 1994  Allen S. Firstenberg
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "standard.H"
#include "cgi-query.H"

/***************************************************************************/

QueryEntry::QueryEntry( char *n, char *v )
{
  // Set the values
  name( n );
  val( v );
}

//---------------------------------------------------------------------------

QueryEntry::~QueryEntry()
{
  // Only free the values if there is something stored there
  if( v_name ) free( v_name );
  if( v_val ) free( v_val );
}

/***************************************************************************/

/*
 * These access the values
 */

char *QueryEntry::name()
{
  return v_name;
}

//---------------------------------------------------------------------------

char *QueryEntry::val()
{
  return v_val;
}

/***************************************************************************/

/*
 * These set the values
 */

char *QueryEntry::name( char *n )
{
  if( n ){
    // Allocate the space and assign
    v_name = (char *)malloc( strlen(n) + 1 );
    strcpy( v_name, n );
  } else {
    // Put the NULL there
    v_name = n;
  }

  return v_name;
}

//---------------------------------------------------------------------------

char *QueryEntry::val( char *v )
{
  if( v ){
    // Allocate the space and assign
    v_val = (char *)malloc( strlen(v) + 1 );
    strcpy( v_val, v );
  } else {
    // Put the NULL there
    v_val = v;
  }

  return v_val;
}

/***************************************************************************/

CgiQuery::CgiQuery( char *method, int max_entries )
{
  /*
   * Most of this code was lifted directly from cgi-src/query.c
   *
   * Check to make sure we are using the appropriate method.
   * If we are, allocate space.
   */
  
  num_entries = 0;

  if( strcmp(getenv("REQUEST_METHOD"),method) ){
    // We can't access it
    entries = NULL;
  } else {
    entries = (QueryEntry *)malloc( max_entries * sizeof(QueryEntry) );
  }
}

//---------------------------------------------------------------------------

CgiQuery::~CgiQuery()
{
  if( entries ){
    free( entries );
  }
}

/***************************************************************************/

// Can this query be done?
int CgiQuery::valid(){
  /*
   * It is only valid if we allocated space and there are entries
   */
  
  if( entries && num_entries ){
    return 1;
  } else {
    return 0;
  }
}

/***************************************************************************/

// Return the value associated with the name
char *CgiQuery::lookup( char *name ){
  char *ret = NULL;
  int co = 0;

  while( (!ret) && (co < num_entries) ){
    if( !strcmp( name, entries[co].name() ) ){
      ret = entries[co].val();
    }
    co++;
  }
    
  return ret;
}

/***************************************************************************/

/*
 * $Log: cgi-query.C,v $
 * Revision 1.2  1994/07/10  09:16:37  asf
 * Added the QueryEntry object.
 *
 * Revision 1.1  1994/07/09  20:07:15  asf
 * Initial revision
 *
 */
